@@ -1,7 +1,6 @@
 import xcffib
 import struct
 import io
-from dataclasses import dataclass
 
 MAJOR_VERSION = 0
 MINOR_VERSION = 0
@@ -10,7 +9,6 @@ _events = {}
 _errors = {}
 
 
-@dataclass(init=False)
 class EnableReply(xcffib.Reply):
     xge = False
 
@@ -23,12 +21,10 @@ class EnableReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class EnableCookie(xcffib.Cookie):
     reply_type = EnableReply
 
 
-@dataclass(init=False)
 class bigreqExtension(xcffib.Extension):
     def Enable(self, is_checked=True):
         buf = io.BytesIO()
