@@ -1,7 +1,6 @@
 import xcffib
 import struct
 import io
-from dataclasses import dataclass
 
 MAJOR_VERSION = 0
 MINOR_VERSION = 4
@@ -12,13 +11,11 @@ from . import xproto
 from . import xfixes
 
 
-@dataclass(init=False)
 class Redirect:
     Automatic = 0
     Manual = 1
 
 
-@dataclass(init=False)
 class QueryVersionReply(xcffib.Reply):
     xge = False
 
@@ -31,12 +28,10 @@ class QueryVersionReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class QueryVersionCookie(xcffib.Cookie):
     reply_type = QueryVersionReply
 
 
-@dataclass(init=False)
 class GetOverlayWindowReply(xcffib.Reply):
     xge = False
 
@@ -49,12 +44,10 @@ class GetOverlayWindowReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetOverlayWindowCookie(xcffib.Cookie):
     reply_type = GetOverlayWindowReply
 
 
-@dataclass(init=False)
 class compositeExtension(xcffib.Extension):
     def QueryVersion(self, client_major_version, client_minor_version, is_checked=True):
         buf = io.BytesIO()
