@@ -1,7 +1,6 @@
 import xcffib
 import struct
 import io
-from dataclasses import dataclass
 
 MAJOR_VERSION = 1
 MINOR_VERSION = 1
@@ -12,7 +11,6 @@ from . import xproto
 from . import xfixes
 
 
-@dataclass(init=False)
 class ReportLevel:
     RawRectangles = 0
     DeltaRectangles = 1
@@ -20,7 +18,6 @@ class ReportLevel:
     NonEmpty = 3
 
 
-@dataclass(init=False)
 class BadDamageError(xcffib.Error):
     xge = False
 
@@ -43,7 +40,6 @@ BadBadDamage = BadDamageError
 _errors[0] = BadDamageError
 
 
-@dataclass(init=False)
 class QueryVersionReply(xcffib.Reply):
     xge = False
 
@@ -56,12 +52,10 @@ class QueryVersionReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class QueryVersionCookie(xcffib.Cookie):
     reply_type = QueryVersionReply
 
 
-@dataclass(init=False)
 class NotifyEvent(xcffib.Event):
     xge = False
 
@@ -116,7 +110,6 @@ class NotifyEvent(xcffib.Event):
 _events[0] = NotifyEvent
 
 
-@dataclass(init=False)
 class damageExtension(xcffib.Extension):
     def QueryVersion(self, client_major_version, client_minor_version, is_checked=True):
         buf = io.BytesIO()
