@@ -1,7 +1,6 @@
 import xcffib
 import struct
 import io
-from dataclasses import dataclass
 
 MAJOR_VERSION = 1
 MINOR_VERSION = 4
@@ -11,7 +10,6 @@ _errors = {}
 from . import xproto
 
 
-@dataclass(init=False)
 class Attachment:
     BufferFrontLeft = 0
     BufferBackLeft = 1
@@ -26,20 +24,17 @@ class Attachment:
     BufferHiz = 10
 
 
-@dataclass(init=False)
 class DriverType:
     DRI = 0
     VDPAU = 1
 
 
-@dataclass(init=False)
 class EventType:
     ExchangeComplete = 1
     BlitComplete = 2
     FlipComplete = 3
 
 
-@dataclass(init=False)
 class DRI2Buffer(xcffib.Struct):
     xge = False
 
@@ -75,7 +70,6 @@ class DRI2Buffer(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class AttachFormat(xcffib.Struct):
     xge = False
 
@@ -102,7 +96,6 @@ class AttachFormat(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class QueryVersionReply(xcffib.Reply):
     xge = False
 
@@ -115,12 +108,10 @@ class QueryVersionReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class QueryVersionCookie(xcffib.Cookie):
     reply_type = QueryVersionReply
 
 
-@dataclass(init=False)
 class ConnectReply(xcffib.Reply):
     xge = False
 
@@ -144,12 +135,10 @@ class ConnectReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class ConnectCookie(xcffib.Cookie):
     reply_type = ConnectReply
 
 
-@dataclass(init=False)
 class AuthenticateReply(xcffib.Reply):
     xge = False
 
@@ -162,12 +151,10 @@ class AuthenticateReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class AuthenticateCookie(xcffib.Cookie):
     reply_type = AuthenticateReply
 
 
-@dataclass(init=False)
 class GetBuffersReply(xcffib.Reply):
     xge = False
 
@@ -181,12 +168,10 @@ class GetBuffersReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetBuffersCookie(xcffib.Cookie):
     reply_type = GetBuffersReply
 
 
-@dataclass(init=False)
 class CopyRegionReply(xcffib.Reply):
     xge = False
 
@@ -199,12 +184,10 @@ class CopyRegionReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class CopyRegionCookie(xcffib.Cookie):
     reply_type = CopyRegionReply
 
 
-@dataclass(init=False)
 class GetBuffersWithFormatReply(xcffib.Reply):
     xge = False
 
@@ -218,12 +201,10 @@ class GetBuffersWithFormatReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetBuffersWithFormatCookie(xcffib.Cookie):
     reply_type = GetBuffersWithFormatReply
 
 
-@dataclass(init=False)
 class SwapBuffersReply(xcffib.Reply):
     xge = False
 
@@ -236,12 +217,10 @@ class SwapBuffersReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class SwapBuffersCookie(xcffib.Cookie):
     reply_type = SwapBuffersReply
 
 
-@dataclass(init=False)
 class GetMSCReply(xcffib.Reply):
     xge = False
 
@@ -256,12 +235,10 @@ class GetMSCReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetMSCCookie(xcffib.Cookie):
     reply_type = GetMSCReply
 
 
-@dataclass(init=False)
 class WaitMSCReply(xcffib.Reply):
     xge = False
 
@@ -276,12 +253,10 @@ class WaitMSCReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class WaitMSCCookie(xcffib.Cookie):
     reply_type = WaitMSCReply
 
 
-@dataclass(init=False)
 class WaitSBCReply(xcffib.Reply):
     xge = False
 
@@ -296,12 +271,10 @@ class WaitSBCReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class WaitSBCCookie(xcffib.Cookie):
     reply_type = WaitSBCReply
 
 
-@dataclass(init=False)
 class GetParamReply(xcffib.Reply):
     xge = False
 
@@ -316,12 +289,10 @@ class GetParamReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetParamCookie(xcffib.Cookie):
     reply_type = GetParamReply
 
 
-@dataclass(init=False)
 class BufferSwapCompleteEvent(xcffib.Event):
     xge = False
 
@@ -377,7 +348,6 @@ class BufferSwapCompleteEvent(xcffib.Event):
 _events[0] = BufferSwapCompleteEvent
 
 
-@dataclass(init=False)
 class InvalidateBuffersEvent(xcffib.Event):
     xge = False
 
@@ -408,7 +378,6 @@ class InvalidateBuffersEvent(xcffib.Event):
 _events[1] = InvalidateBuffersEvent
 
 
-@dataclass(init=False)
 class dri2Extension(xcffib.Extension):
     def QueryVersion(self, major_version, minor_version, is_checked=True):
         buf = io.BytesIO()
