@@ -1,7 +1,6 @@
 import xcffib
 import struct
 import io
-from dataclasses import dataclass
 
 MAJOR_VERSION = 1
 MINOR_VERSION = 0
@@ -10,7 +9,6 @@ _events = {}
 _errors = {}
 
 
-@dataclass(init=False)
 class QueryVersionReply(xcffib.Reply):
     xge = False
 
@@ -23,12 +21,10 @@ class QueryVersionReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class QueryVersionCookie(xcffib.Cookie):
     reply_type = QueryVersionReply
 
 
-@dataclass(init=False)
 class geExtension(xcffib.Extension):
     def QueryVersion(self, client_major_version, client_minor_version, is_checked=True):
         buf = io.BytesIO()
