@@ -1,7 +1,6 @@
 import xcffib
 import struct
 import io
-from dataclasses import dataclass
 
 MAJOR_VERSION = 1
 MINOR_VERSION = 6
@@ -12,7 +11,6 @@ from . import xproto
 from . import render
 
 
-@dataclass(init=False)
 class BadOutputError(xcffib.Error):
     xge = False
 
@@ -35,7 +33,6 @@ BadBadOutput = BadOutputError
 _errors[0] = BadOutputError
 
 
-@dataclass(init=False)
 class BadCrtcError(xcffib.Error):
     xge = False
 
@@ -58,7 +55,6 @@ BadBadCrtc = BadCrtcError
 _errors[1] = BadCrtcError
 
 
-@dataclass(init=False)
 class BadModeError(xcffib.Error):
     xge = False
 
@@ -81,7 +77,6 @@ BadBadMode = BadModeError
 _errors[2] = BadModeError
 
 
-@dataclass(init=False)
 class BadProviderError(xcffib.Error):
     xge = False
 
@@ -104,7 +99,6 @@ BadBadProvider = BadProviderError
 _errors[3] = BadProviderError
 
 
-@dataclass(init=False)
 class Rotation:
     Rotate_0 = 1 << 0
     Rotate_90 = 1 << 1
@@ -114,7 +108,6 @@ class Rotation:
     Reflect_Y = 1 << 5
 
 
-@dataclass(init=False)
 class ScreenSize(xcffib.Struct):
     xge = False
 
@@ -145,7 +138,6 @@ class ScreenSize(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class RefreshRates(xcffib.Struct):
     xge = False
 
@@ -172,7 +164,6 @@ class RefreshRates(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class QueryVersionReply(xcffib.Reply):
     xge = False
 
@@ -185,12 +176,10 @@ class QueryVersionReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class QueryVersionCookie(xcffib.Cookie):
     reply_type = QueryVersionReply
 
 
-@dataclass(init=False)
 class SetConfig:
     Success = 0
     InvalidConfigTime = 1
@@ -198,7 +187,6 @@ class SetConfig:
     Failed = 3
 
 
-@dataclass(init=False)
 class SetScreenConfigReply(xcffib.Reply):
     xge = False
 
@@ -217,12 +205,10 @@ class SetScreenConfigReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class SetScreenConfigCookie(xcffib.Cookie):
     reply_type = SetScreenConfigReply
 
 
-@dataclass(init=False)
 class NotifyMask:
     ScreenChange = 1 << 0
     CrtcChange = 1 << 1
@@ -234,7 +220,6 @@ class NotifyMask:
     Lease = 1 << 7
 
 
-@dataclass(init=False)
 class GetScreenInfoReply(xcffib.Reply):
     xge = False
 
@@ -260,12 +245,10 @@ class GetScreenInfoReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetScreenInfoCookie(xcffib.Cookie):
     reply_type = GetScreenInfoReply
 
 
-@dataclass(init=False)
 class GetScreenSizeRangeReply(xcffib.Reply):
     xge = False
 
@@ -280,12 +263,10 @@ class GetScreenSizeRangeReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetScreenSizeRangeCookie(xcffib.Cookie):
     reply_type = GetScreenSizeRangeReply
 
 
-@dataclass(init=False)
 class ModeFlag:
     HsyncPositive = 1 << 0
     HsyncNegative = 1 << 1
@@ -303,7 +284,6 @@ class ModeFlag:
     HalveClock = 1 << 13
 
 
-@dataclass(init=False)
 class ModeInfo(xcffib.Struct):
     xge = False
 
@@ -387,7 +367,6 @@ class ModeInfo(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class GetScreenResourcesReply(xcffib.Reply):
     xge = False
 
@@ -414,19 +393,16 @@ class GetScreenResourcesReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetScreenResourcesCookie(xcffib.Cookie):
     reply_type = GetScreenResourcesReply
 
 
-@dataclass(init=False)
 class Connection:
     Connected = 0
     Disconnected = 1
     Unknown = 2
 
 
-@dataclass(init=False)
 class GetOutputInfoReply(xcffib.Reply):
     xge = False
 
@@ -459,12 +435,10 @@ class GetOutputInfoReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetOutputInfoCookie(xcffib.Cookie):
     reply_type = GetOutputInfoReply
 
 
-@dataclass(init=False)
 class ListOutputPropertiesReply(xcffib.Reply):
     xge = False
 
@@ -478,12 +452,10 @@ class ListOutputPropertiesReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class ListOutputPropertiesCookie(xcffib.Cookie):
     reply_type = ListOutputPropertiesReply
 
 
-@dataclass(init=False)
 class QueryOutputPropertyReply(xcffib.Reply):
     xge = False
 
@@ -497,12 +469,10 @@ class QueryOutputPropertyReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class QueryOutputPropertyCookie(xcffib.Cookie):
     reply_type = QueryOutputPropertyReply
 
 
-@dataclass(init=False)
 class GetOutputPropertyReply(xcffib.Reply):
     xge = False
 
@@ -518,12 +488,10 @@ class GetOutputPropertyReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetOutputPropertyCookie(xcffib.Cookie):
     reply_type = GetOutputPropertyReply
 
 
-@dataclass(init=False)
 class CreateModeReply(xcffib.Reply):
     xge = False
 
@@ -536,12 +504,10 @@ class CreateModeReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class CreateModeCookie(xcffib.Cookie):
     reply_type = CreateModeReply
 
 
-@dataclass(init=False)
 class GetCrtcInfoReply(xcffib.Reply):
     xge = False
 
@@ -569,12 +535,10 @@ class GetCrtcInfoReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetCrtcInfoCookie(xcffib.Cookie):
     reply_type = GetCrtcInfoReply
 
 
-@dataclass(init=False)
 class SetCrtcConfigReply(xcffib.Reply):
     xge = False
 
@@ -587,12 +551,10 @@ class SetCrtcConfigReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class SetCrtcConfigCookie(xcffib.Cookie):
     reply_type = SetCrtcConfigReply
 
 
-@dataclass(init=False)
 class GetCrtcGammaSizeReply(xcffib.Reply):
     xge = False
 
@@ -605,12 +567,10 @@ class GetCrtcGammaSizeReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetCrtcGammaSizeCookie(xcffib.Cookie):
     reply_type = GetCrtcGammaSizeReply
 
 
-@dataclass(init=False)
 class GetCrtcGammaReply(xcffib.Reply):
     xge = False
 
@@ -628,12 +588,10 @@ class GetCrtcGammaReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetCrtcGammaCookie(xcffib.Cookie):
     reply_type = GetCrtcGammaReply
 
 
-@dataclass(init=False)
 class GetScreenResourcesCurrentReply(xcffib.Reply):
     xge = False
 
@@ -660,12 +618,10 @@ class GetScreenResourcesCurrentReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetScreenResourcesCurrentCookie(xcffib.Cookie):
     reply_type = GetScreenResourcesCurrentReply
 
 
-@dataclass(init=False)
 class Transform:
     Unit = 1 << 0
     ScaleUp = 1 << 1
@@ -673,7 +629,6 @@ class Transform:
     Projective = 1 << 3
 
 
-@dataclass(init=False)
 class GetCrtcTransformReply(xcffib.Reply):
     xge = False
 
@@ -704,12 +659,10 @@ class GetCrtcTransformReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetCrtcTransformCookie(xcffib.Cookie):
     reply_type = GetCrtcTransformReply
 
 
-@dataclass(init=False)
 class GetPanningReply(xcffib.Reply):
     xge = False
 
@@ -737,12 +690,10 @@ class GetPanningReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetPanningCookie(xcffib.Cookie):
     reply_type = GetPanningReply
 
 
-@dataclass(init=False)
 class SetPanningReply(xcffib.Reply):
     xge = False
 
@@ -755,12 +706,10 @@ class SetPanningReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class SetPanningCookie(xcffib.Cookie):
     reply_type = SetPanningReply
 
 
-@dataclass(init=False)
 class GetOutputPrimaryReply(xcffib.Reply):
     xge = False
 
@@ -773,12 +722,10 @@ class GetOutputPrimaryReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetOutputPrimaryCookie(xcffib.Cookie):
     reply_type = GetOutputPrimaryReply
 
 
-@dataclass(init=False)
 class GetProvidersReply(xcffib.Reply):
     xge = False
 
@@ -792,12 +739,10 @@ class GetProvidersReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetProvidersCookie(xcffib.Cookie):
     reply_type = GetProvidersReply
 
 
-@dataclass(init=False)
 class ProviderCapability:
     SourceOutput = 1 << 0
     SinkOutput = 1 << 1
@@ -805,7 +750,6 @@ class ProviderCapability:
     SinkOffload = 1 << 3
 
 
-@dataclass(init=False)
 class GetProviderInfoReply(xcffib.Reply):
     xge = False
 
@@ -839,12 +783,10 @@ class GetProviderInfoReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetProviderInfoCookie(xcffib.Cookie):
     reply_type = GetProviderInfoReply
 
 
-@dataclass(init=False)
 class ListProviderPropertiesReply(xcffib.Reply):
     xge = False
 
@@ -858,12 +800,10 @@ class ListProviderPropertiesReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class ListProviderPropertiesCookie(xcffib.Cookie):
     reply_type = ListProviderPropertiesReply
 
 
-@dataclass(init=False)
 class QueryProviderPropertyReply(xcffib.Reply):
     xge = False
 
@@ -877,12 +817,10 @@ class QueryProviderPropertyReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class QueryProviderPropertyCookie(xcffib.Cookie):
     reply_type = QueryProviderPropertyReply
 
 
-@dataclass(init=False)
 class GetProviderPropertyReply(xcffib.Reply):
     xge = False
 
@@ -898,12 +836,10 @@ class GetProviderPropertyReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetProviderPropertyCookie(xcffib.Cookie):
     reply_type = GetProviderPropertyReply
 
 
-@dataclass(init=False)
 class ScreenChangeNotifyEvent(xcffib.Event):
     xge = False
 
@@ -984,7 +920,6 @@ class ScreenChangeNotifyEvent(xcffib.Event):
 _events[0] = ScreenChangeNotifyEvent
 
 
-@dataclass(init=False)
 class Notify:
     CrtcChange = 0
     OutputChange = 1
@@ -995,7 +930,6 @@ class Notify:
     Lease = 6
 
 
-@dataclass(init=False)
 class CrtcChange(xcffib.Struct):
     xge = False
 
@@ -1052,7 +986,6 @@ class CrtcChange(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class OutputChange(xcffib.Struct):
     xge = False
 
@@ -1120,7 +1053,6 @@ class OutputChange(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class OutputProperty(xcffib.Struct):
     xge = False
 
@@ -1161,7 +1093,6 @@ class OutputProperty(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class ProviderChange(xcffib.Struct):
     xge = False
 
@@ -1189,7 +1120,6 @@ class ProviderChange(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class ProviderProperty(xcffib.Struct):
     xge = False
 
@@ -1230,7 +1160,6 @@ class ProviderProperty(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class ResourceChange(xcffib.Struct):
     xge = False
 
@@ -1257,7 +1186,6 @@ class ResourceChange(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class MonitorInfo(xcffib.Struct):
     xge = False
 
@@ -1331,7 +1259,6 @@ class MonitorInfo(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class GetMonitorsReply(xcffib.Reply):
     xge = False
 
@@ -1345,12 +1272,10 @@ class GetMonitorsReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetMonitorsCookie(xcffib.Cookie):
     reply_type = GetMonitorsReply
 
 
-@dataclass(init=False)
 class CreateLeaseReply(xcffib.Reply):
     xge = False
 
@@ -1363,12 +1288,10 @@ class CreateLeaseReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class CreateLeaseCookie(xcffib.Cookie):
     reply_type = CreateLeaseReply
 
 
-@dataclass(init=False)
 class LeaseNotify(xcffib.Struct):
     xge = False
 
@@ -1403,7 +1326,6 @@ class LeaseNotify(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class NotifyData(xcffib.Union):
     xge = False
 
@@ -1429,7 +1351,6 @@ class NotifyData(xcffib.Union):
         return buf.getvalue()
 
 
-@dataclass(init=False)
 class NotifyEvent(xcffib.Event):
     xge = False
 
@@ -1467,7 +1388,6 @@ class NotifyEvent(xcffib.Event):
 _events[1] = NotifyEvent
 
 
-@dataclass(init=False)
 class randrExtension(xcffib.Extension):
     def QueryVersion(self, major_version, minor_version, is_checked=True):
         buf = io.BytesIO()
