@@ -1,7 +1,6 @@
 import xcffib
 import struct
 import io
-from dataclasses import dataclass
 
 MAJOR_VERSION = 0
 MINOR_VERSION = 11
@@ -11,18 +10,15 @@ _errors = {}
 from . import xproto
 
 
-@dataclass(init=False)
 class PictType:
     Indexed = 0
     Direct = 1
 
 
-@dataclass(init=False)
 class Picture:
     _None = 0
 
 
-@dataclass(init=False)
 class PictOp:
     Clear = 0
     Src = 1
@@ -79,19 +75,16 @@ class PictOp:
     HSLLuminosity = 62
 
 
-@dataclass(init=False)
 class PolyEdge:
     Sharp = 0
     Smooth = 1
 
 
-@dataclass(init=False)
 class PolyMode:
     Precise = 0
     Imprecise = 1
 
 
-@dataclass(init=False)
 class CP:
     Repeat = 1 << 0
     AlphaMap = 1 << 1
@@ -108,7 +101,6 @@ class CP:
     ComponentAlpha = 1 << 12
 
 
-@dataclass(init=False)
 class SubPixel:
     Unknown = 0
     HorizontalRGB = 1
@@ -118,7 +110,6 @@ class SubPixel:
     _None = 5
 
 
-@dataclass(init=False)
 class Repeat:
     _None = 0
     Normal = 1
@@ -126,7 +117,6 @@ class Repeat:
     Reflect = 3
 
 
-@dataclass(init=False)
 class PictFormatError(xcffib.Error):
     xge = False
 
@@ -149,7 +139,6 @@ BadPictFormat = PictFormatError
 _errors[0] = PictFormatError
 
 
-@dataclass(init=False)
 class PictureError(xcffib.Error):
     xge = False
 
@@ -172,7 +161,6 @@ BadPicture = PictureError
 _errors[1] = PictureError
 
 
-@dataclass(init=False)
 class PictOpError(xcffib.Error):
     xge = False
 
@@ -195,7 +183,6 @@ BadPictOp = PictOpError
 _errors[2] = PictOpError
 
 
-@dataclass(init=False)
 class GlyphSetError(xcffib.Error):
     xge = False
 
@@ -218,7 +205,6 @@ BadGlyphSet = GlyphSetError
 _errors[3] = GlyphSetError
 
 
-@dataclass(init=False)
 class GlyphError(xcffib.Error):
     xge = False
 
@@ -241,7 +227,6 @@ BadGlyph = GlyphError
 _errors[4] = GlyphError
 
 
-@dataclass(init=False)
 class DIRECTFORMAT(xcffib.Struct):
     xge = False
 
@@ -305,7 +290,6 @@ class DIRECTFORMAT(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class PICTFORMINFO(xcffib.Struct):
     xge = False
 
@@ -341,7 +325,6 @@ class PICTFORMINFO(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class PICTVISUAL(xcffib.Struct):
     xge = False
 
@@ -368,7 +351,6 @@ class PICTVISUAL(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class PICTDEPTH(xcffib.Struct):
     xge = False
 
@@ -396,7 +378,6 @@ class PICTDEPTH(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class PICTSCREEN(xcffib.Struct):
     xge = False
 
@@ -424,7 +405,6 @@ class PICTSCREEN(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class INDEXVALUE(xcffib.Struct):
     xge = False
 
@@ -460,7 +440,6 @@ class INDEXVALUE(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class COLOR(xcffib.Struct):
     xge = False
 
@@ -489,7 +468,6 @@ class COLOR(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class POINTFIX(xcffib.Struct):
     xge = False
 
@@ -516,7 +494,6 @@ class POINTFIX(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class LINEFIX(xcffib.Struct):
     xge = False
 
@@ -552,7 +529,6 @@ class LINEFIX(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class TRIANGLE(xcffib.Struct):
     xge = False
 
@@ -596,7 +572,6 @@ class TRIANGLE(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class TRAPEZOID(xcffib.Struct):
     xge = False
 
@@ -636,7 +611,6 @@ class TRAPEZOID(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class GLYPHINFO(xcffib.Struct):
     xge = False
 
@@ -679,7 +653,6 @@ class GLYPHINFO(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class QueryVersionReply(xcffib.Reply):
     xge = False
 
@@ -692,12 +665,10 @@ class QueryVersionReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class QueryVersionCookie(xcffib.Cookie):
     reply_type = QueryVersionReply
 
 
-@dataclass(init=False)
 class QueryPictFormatsReply(xcffib.Reply):
     xge = False
 
@@ -721,12 +692,10 @@ class QueryPictFormatsReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class QueryPictFormatsCookie(xcffib.Cookie):
     reply_type = QueryPictFormatsReply
 
 
-@dataclass(init=False)
 class QueryPictIndexValuesReply(xcffib.Reply):
     xge = False
 
@@ -740,12 +709,10 @@ class QueryPictIndexValuesReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class QueryPictIndexValuesCookie(xcffib.Cookie):
     reply_type = QueryPictIndexValuesReply
 
 
-@dataclass(init=False)
 class TRANSFORM(xcffib.Struct):
     xge = False
 
@@ -813,7 +780,6 @@ class TRANSFORM(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class QueryFiltersReply(xcffib.Reply):
     xge = False
 
@@ -829,12 +795,10 @@ class QueryFiltersReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class QueryFiltersCookie(xcffib.Cookie):
     reply_type = QueryFiltersReply
 
 
-@dataclass(init=False)
 class ANIMCURSORELT(xcffib.Struct):
     xge = False
 
@@ -861,7 +825,6 @@ class ANIMCURSORELT(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class SPANFIX(xcffib.Struct):
     xge = False
 
@@ -889,7 +852,6 @@ class SPANFIX(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class TRAP(xcffib.Struct):
     xge = False
 
@@ -925,7 +887,6 @@ class TRAP(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class renderExtension(xcffib.Extension):
     def QueryVersion(self, client_major_version, client_minor_version, is_checked=True):
         buf = io.BytesIO()
