@@ -1,7 +1,6 @@
 import xcffib
 import struct
 import io
-from dataclasses import dataclass
 
 MAJOR_VERSION = 1
 MINOR_VERSION = 2
@@ -11,7 +10,6 @@ _errors = {}
 from . import xproto
 
 
-@dataclass(init=False)
 class Client(xcffib.Struct):
     xge = False
 
@@ -38,7 +36,6 @@ class Client(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class Type(xcffib.Struct):
     xge = False
 
@@ -65,13 +62,11 @@ class Type(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class ClientIdMask:
     ClientXID = 1 << 0
     LocalClientPID = 1 << 1
 
 
-@dataclass(init=False)
 class ClientIdSpec(xcffib.Struct):
     xge = False
 
@@ -98,7 +93,6 @@ class ClientIdSpec(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class ClientIdValue(xcffib.Struct):
     xge = False
 
@@ -133,7 +127,6 @@ class ClientIdValue(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class ResourceIdSpec(xcffib.Struct):
     xge = False
 
@@ -160,7 +153,6 @@ class ResourceIdSpec(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class ResourceSizeSpec(xcffib.Struct):
     xge = False
 
@@ -195,7 +187,6 @@ class ResourceSizeSpec(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class ResourceSizeValue(xcffib.Struct):
     xge = False
 
@@ -232,7 +223,6 @@ class ResourceSizeValue(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class QueryVersionReply(xcffib.Reply):
     xge = False
 
@@ -245,12 +235,10 @@ class QueryVersionReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class QueryVersionCookie(xcffib.Cookie):
     reply_type = QueryVersionReply
 
 
-@dataclass(init=False)
 class QueryClientsReply(xcffib.Reply):
     xge = False
 
@@ -264,12 +252,10 @@ class QueryClientsReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class QueryClientsCookie(xcffib.Cookie):
     reply_type = QueryClientsReply
 
 
-@dataclass(init=False)
 class QueryClientResourcesReply(xcffib.Reply):
     xge = False
 
@@ -283,12 +269,10 @@ class QueryClientResourcesReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class QueryClientResourcesCookie(xcffib.Cookie):
     reply_type = QueryClientResourcesReply
 
 
-@dataclass(init=False)
 class QueryClientPixmapBytesReply(xcffib.Reply):
     xge = False
 
@@ -301,12 +285,10 @@ class QueryClientPixmapBytesReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class QueryClientPixmapBytesCookie(xcffib.Cookie):
     reply_type = QueryClientPixmapBytesReply
 
 
-@dataclass(init=False)
 class QueryClientIdsReply(xcffib.Reply):
     xge = False
 
@@ -320,12 +302,10 @@ class QueryClientIdsReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class QueryClientIdsCookie(xcffib.Cookie):
     reply_type = QueryClientIdsReply
 
 
-@dataclass(init=False)
 class QueryResourceBytesReply(xcffib.Reply):
     xge = False
 
@@ -339,12 +319,10 @@ class QueryResourceBytesReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class QueryResourceBytesCookie(xcffib.Cookie):
     reply_type = QueryResourceBytesReply
 
 
-@dataclass(init=False)
 class resExtension(xcffib.Extension):
     def QueryVersion(self, client_major, client_minor, is_checked=True):
         buf = io.BytesIO()
