@@ -1,7 +1,6 @@
 import xcffib
 import struct
 import io
-from dataclasses import dataclass
 
 MAJOR_VERSION = 1
 MINOR_VERSION = 1
@@ -11,7 +10,6 @@ _errors = {}
 from . import xproto
 
 
-@dataclass(init=False)
 class SO:
     Set = 0
     Union = 1
@@ -20,14 +18,12 @@ class SO:
     Invert = 4
 
 
-@dataclass(init=False)
 class SK:
     Bounding = 0
     Clip = 1
     Input = 2
 
 
-@dataclass(init=False)
 class NotifyEvent(xcffib.Event):
     xge = False
 
@@ -96,7 +92,6 @@ class NotifyEvent(xcffib.Event):
 _events[0] = NotifyEvent
 
 
-@dataclass(init=False)
 class QueryVersionReply(xcffib.Reply):
     xge = False
 
@@ -109,12 +104,10 @@ class QueryVersionReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class QueryVersionCookie(xcffib.Cookie):
     reply_type = QueryVersionReply
 
 
-@dataclass(init=False)
 class QueryExtentsReply(xcffib.Reply):
     xge = False
 
@@ -138,12 +131,10 @@ class QueryExtentsReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class QueryExtentsCookie(xcffib.Cookie):
     reply_type = QueryExtentsReply
 
 
-@dataclass(init=False)
 class InputSelectedReply(xcffib.Reply):
     xge = False
 
@@ -156,12 +147,10 @@ class InputSelectedReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class InputSelectedCookie(xcffib.Cookie):
     reply_type = InputSelectedReply
 
 
-@dataclass(init=False)
 class GetRectanglesReply(xcffib.Reply):
     xge = False
 
@@ -175,12 +164,10 @@ class GetRectanglesReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetRectanglesCookie(xcffib.Cookie):
     reply_type = GetRectanglesReply
 
 
-@dataclass(init=False)
 class shapeExtension(xcffib.Extension):
     def QueryVersion(self, is_checked=True):
         buf = io.BytesIO()
