@@ -1,7 +1,6 @@
 import xcffib
 import struct
 import io
-from dataclasses import dataclass
 
 MAJOR_VERSION = 1
 MINOR_VERSION = 2
@@ -11,7 +10,6 @@ _errors = {}
 from . import xproto
 
 
-@dataclass(init=False)
 class CompletionEvent(xcffib.Event):
     xge = False
 
@@ -57,7 +55,6 @@ class CompletionEvent(xcffib.Event):
 _events[0] = CompletionEvent
 
 
-@dataclass(init=False)
 class BadSegError(xcffib.Error):
     xge = False
 
@@ -86,7 +83,6 @@ BadBadSeg = BadSegError
 _errors[0] = BadSegError
 
 
-@dataclass(init=False)
 class QueryVersionReply(xcffib.Reply):
     xge = False
 
@@ -106,12 +102,10 @@ class QueryVersionReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class QueryVersionCookie(xcffib.Cookie):
     reply_type = QueryVersionReply
 
 
-@dataclass(init=False)
 class GetImageReply(xcffib.Reply):
     xge = False
 
@@ -124,12 +118,10 @@ class GetImageReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetImageCookie(xcffib.Cookie):
     reply_type = GetImageReply
 
 
-@dataclass(init=False)
 class CreateSegmentReply(xcffib.Reply):
     xge = False
 
@@ -142,12 +134,10 @@ class CreateSegmentReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class CreateSegmentCookie(xcffib.Cookie):
     reply_type = CreateSegmentReply
 
 
-@dataclass(init=False)
 class shmExtension(xcffib.Extension):
     def QueryVersion(self, is_checked=True):
         buf = io.BytesIO()
