@@ -1,7 +1,6 @@
 import xcffib
 import struct
 import io
-from dataclasses import dataclass
 
 MAJOR_VERSION = 3
 MINOR_VERSION = 1
@@ -11,14 +10,12 @@ _errors = {}
 from . import xproto
 
 
-@dataclass(init=False)
 class ALARMSTATE:
     Active = 0
     Inactive = 1
     Destroyed = 2
 
 
-@dataclass(init=False)
 class TESTTYPE:
     PositiveTransition = 0
     NegativeTransition = 1
@@ -26,13 +23,11 @@ class TESTTYPE:
     NegativeComparison = 3
 
 
-@dataclass(init=False)
 class VALUETYPE:
     Absolute = 0
     Relative = 1
 
 
-@dataclass(init=False)
 class CA:
     Counter = 1 << 0
     ValueType = 1 << 1
@@ -42,7 +37,6 @@ class CA:
     Events = 1 << 5
 
 
-@dataclass(init=False)
 class INT64(xcffib.Struct):
     xge = False
 
@@ -69,7 +63,6 @@ class INT64(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class SYSTEMCOUNTER(xcffib.Struct):
     xge = False
 
@@ -112,7 +105,6 @@ class SYSTEMCOUNTER(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class TRIGGER(xcffib.Struct):
     xge = False
 
@@ -147,7 +139,6 @@ class TRIGGER(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class WAITCONDITION(xcffib.Struct):
     xge = False
 
@@ -183,7 +174,6 @@ class WAITCONDITION(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class CounterError(xcffib.Error):
     xge = False
 
@@ -212,7 +202,6 @@ BadCounter = CounterError
 _errors[0] = CounterError
 
 
-@dataclass(init=False)
 class AlarmError(xcffib.Error):
     xge = False
 
@@ -239,7 +228,6 @@ BadAlarm = AlarmError
 _errors[1] = AlarmError
 
 
-@dataclass(init=False)
 class InitializeReply(xcffib.Reply):
     xge = False
 
@@ -252,12 +240,10 @@ class InitializeReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class InitializeCookie(xcffib.Cookie):
     reply_type = InitializeReply
 
 
-@dataclass(init=False)
 class ListSystemCountersReply(xcffib.Reply):
     xge = False
 
@@ -271,12 +257,10 @@ class ListSystemCountersReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class ListSystemCountersCookie(xcffib.Cookie):
     reply_type = ListSystemCountersReply
 
 
-@dataclass(init=False)
 class QueryCounterReply(xcffib.Reply):
     xge = False
 
@@ -290,12 +274,10 @@ class QueryCounterReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class QueryCounterCookie(xcffib.Cookie):
     reply_type = QueryCounterReply
 
 
-@dataclass(init=False)
 class QueryAlarmReply(xcffib.Reply):
     xge = False
 
@@ -312,12 +294,10 @@ class QueryAlarmReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class QueryAlarmCookie(xcffib.Cookie):
     reply_type = QueryAlarmReply
 
 
-@dataclass(init=False)
 class GetPriorityReply(xcffib.Reply):
     xge = False
 
@@ -330,12 +310,10 @@ class GetPriorityReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetPriorityCookie(xcffib.Cookie):
     reply_type = GetPriorityReply
 
 
-@dataclass(init=False)
 class QueryFenceReply(xcffib.Reply):
     xge = False
 
@@ -348,12 +326,10 @@ class QueryFenceReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class QueryFenceCookie(xcffib.Cookie):
     reply_type = QueryFenceReply
 
 
-@dataclass(init=False)
 class CounterNotifyEvent(xcffib.Event):
     xge = False
 
@@ -414,7 +390,6 @@ class CounterNotifyEvent(xcffib.Event):
 _events[0] = CounterNotifyEvent
 
 
-@dataclass(init=False)
 class AlarmNotifyEvent(xcffib.Event):
     xge = False
 
@@ -471,7 +446,6 @@ class AlarmNotifyEvent(xcffib.Event):
 _events[1] = AlarmNotifyEvent
 
 
-@dataclass(init=False)
 class syncExtension(xcffib.Extension):
     def Initialize(self, desired_major_version, desired_minor_version, is_checked=True):
         buf = io.BytesIO()
