@@ -1,7 +1,6 @@
 import xcffib
 import struct
 import io
-from dataclasses import dataclass
 
 MAJOR_VERSION = 2
 MINOR_VERSION = 2
@@ -10,7 +9,6 @@ _events = {}
 _errors = {}
 
 
-@dataclass(init=False)
 class ModeFlag:
     Positive_HSync = 1 << 0
     Negative_HSync = 1 << 1
@@ -27,18 +25,15 @@ class ModeFlag:
     Half_Clock = 1 << 12
 
 
-@dataclass(init=False)
 class ClockFlag:
     Programable = 1 << 0
 
 
-@dataclass(init=False)
 class Permission:
     Read = 1 << 0
     Write = 1 << 1
 
 
-@dataclass(init=False)
 class ModeInfo(xcffib.Struct):
     xge = False
 
@@ -118,7 +113,6 @@ class ModeInfo(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class QueryVersionReply(xcffib.Reply):
     xge = False
 
@@ -131,12 +125,10 @@ class QueryVersionReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class QueryVersionCookie(xcffib.Cookie):
     reply_type = QueryVersionReply
 
 
-@dataclass(init=False)
 class GetModeLineReply(xcffib.Reply):
     xge = False
 
@@ -163,12 +155,10 @@ class GetModeLineReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetModeLineCookie(xcffib.Cookie):
     reply_type = GetModeLineReply
 
 
-@dataclass(init=False)
 class GetMonitorReply(xcffib.Reply):
     xge = False
 
@@ -194,12 +184,10 @@ class GetMonitorReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetMonitorCookie(xcffib.Cookie):
     reply_type = GetMonitorReply
 
 
-@dataclass(init=False)
 class GetAllModeLinesReply(xcffib.Reply):
     xge = False
 
@@ -213,12 +201,10 @@ class GetAllModeLinesReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetAllModeLinesCookie(xcffib.Cookie):
     reply_type = GetAllModeLinesReply
 
 
-@dataclass(init=False)
 class ValidateModeLineReply(xcffib.Reply):
     xge = False
 
@@ -231,12 +217,10 @@ class ValidateModeLineReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class ValidateModeLineCookie(xcffib.Cookie):
     reply_type = ValidateModeLineReply
 
 
-@dataclass(init=False)
 class GetViewPortReply(xcffib.Reply):
     xge = False
 
@@ -249,12 +233,10 @@ class GetViewPortReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetViewPortCookie(xcffib.Cookie):
     reply_type = GetViewPortReply
 
 
-@dataclass(init=False)
 class GetDotClocksReply(xcffib.Reply):
     xge = False
 
@@ -268,12 +250,10 @@ class GetDotClocksReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetDotClocksCookie(xcffib.Cookie):
     reply_type = GetDotClocksReply
 
 
-@dataclass(init=False)
 class GetGammaReply(xcffib.Reply):
     xge = False
 
@@ -286,12 +266,10 @@ class GetGammaReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetGammaCookie(xcffib.Cookie):
     reply_type = GetGammaReply
 
 
-@dataclass(init=False)
 class GetGammaRampReply(xcffib.Reply):
     xge = False
 
@@ -309,12 +287,10 @@ class GetGammaRampReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetGammaRampCookie(xcffib.Cookie):
     reply_type = GetGammaRampReply
 
 
-@dataclass(init=False)
 class GetGammaRampSizeReply(xcffib.Reply):
     xge = False
 
@@ -327,12 +303,10 @@ class GetGammaRampSizeReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetGammaRampSizeCookie(xcffib.Cookie):
     reply_type = GetGammaRampSizeReply
 
 
-@dataclass(init=False)
 class GetPermissionsReply(xcffib.Reply):
     xge = False
 
@@ -345,12 +319,10 @@ class GetPermissionsReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetPermissionsCookie(xcffib.Cookie):
     reply_type = GetPermissionsReply
 
 
-@dataclass(init=False)
 class BadClockError(xcffib.Error):
     xge = False
 
@@ -373,7 +345,6 @@ BadBadClock = BadClockError
 _errors[0] = BadClockError
 
 
-@dataclass(init=False)
 class BadHTimingsError(xcffib.Error):
     xge = False
 
@@ -396,7 +367,6 @@ BadBadHTimings = BadHTimingsError
 _errors[1] = BadHTimingsError
 
 
-@dataclass(init=False)
 class BadVTimingsError(xcffib.Error):
     xge = False
 
@@ -419,7 +389,6 @@ BadBadVTimings = BadVTimingsError
 _errors[2] = BadVTimingsError
 
 
-@dataclass(init=False)
 class ModeUnsuitableError(xcffib.Error):
     xge = False
 
@@ -442,7 +411,6 @@ BadModeUnsuitable = ModeUnsuitableError
 _errors[3] = ModeUnsuitableError
 
 
-@dataclass(init=False)
 class ExtensionDisabledError(xcffib.Error):
     xge = False
 
@@ -465,7 +433,6 @@ BadExtensionDisabled = ExtensionDisabledError
 _errors[4] = ExtensionDisabledError
 
 
-@dataclass(init=False)
 class ClientNotLocalError(xcffib.Error):
     xge = False
 
@@ -488,7 +455,6 @@ BadClientNotLocal = ClientNotLocalError
 _errors[5] = ClientNotLocalError
 
 
-@dataclass(init=False)
 class ZoomLockedError(xcffib.Error):
     xge = False
 
@@ -511,7 +477,6 @@ BadZoomLocked = ZoomLockedError
 _errors[6] = ZoomLockedError
 
 
-@dataclass(init=False)
 class xf86vidmodeExtension(xcffib.Extension):
     def QueryVersion(self, is_checked=True):
         buf = io.BytesIO()
