@@ -1,7 +1,6 @@
 import xcffib
 import struct
 import io
-from dataclasses import dataclass
 
 MAJOR_VERSION = 1
 MINOR_VERSION = 0
@@ -11,7 +10,6 @@ _errors = {}
 from . import xproto
 
 
-@dataclass(init=False)
 class QueryVersionReply(xcffib.Reply):
     xge = False
 
@@ -24,12 +22,10 @@ class QueryVersionReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class QueryVersionCookie(xcffib.Cookie):
     reply_type = QueryVersionReply
 
 
-@dataclass(init=False)
 class GetDeviceCreateContextReply(xcffib.Reply):
     xge = False
 
@@ -43,12 +39,10 @@ class GetDeviceCreateContextReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetDeviceCreateContextCookie(xcffib.Cookie):
     reply_type = GetDeviceCreateContextReply
 
 
-@dataclass(init=False)
 class GetDeviceContextReply(xcffib.Reply):
     xge = False
 
@@ -62,12 +56,10 @@ class GetDeviceContextReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetDeviceContextCookie(xcffib.Cookie):
     reply_type = GetDeviceContextReply
 
 
-@dataclass(init=False)
 class GetWindowCreateContextReply(xcffib.Reply):
     xge = False
 
@@ -81,12 +73,10 @@ class GetWindowCreateContextReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetWindowCreateContextCookie(xcffib.Cookie):
     reply_type = GetWindowCreateContextReply
 
 
-@dataclass(init=False)
 class GetWindowContextReply(xcffib.Reply):
     xge = False
 
@@ -100,12 +90,10 @@ class GetWindowContextReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetWindowContextCookie(xcffib.Cookie):
     reply_type = GetWindowContextReply
 
 
-@dataclass(init=False)
 class ListItem(xcffib.Struct):
     xge = False
 
@@ -156,7 +144,6 @@ class ListItem(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class GetPropertyCreateContextReply(xcffib.Reply):
     xge = False
 
@@ -170,12 +157,10 @@ class GetPropertyCreateContextReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetPropertyCreateContextCookie(xcffib.Cookie):
     reply_type = GetPropertyCreateContextReply
 
 
-@dataclass(init=False)
 class GetPropertyUseContextReply(xcffib.Reply):
     xge = False
 
@@ -189,12 +174,10 @@ class GetPropertyUseContextReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetPropertyUseContextCookie(xcffib.Cookie):
     reply_type = GetPropertyUseContextReply
 
 
-@dataclass(init=False)
 class GetPropertyContextReply(xcffib.Reply):
     xge = False
 
@@ -208,12 +191,10 @@ class GetPropertyContextReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetPropertyContextCookie(xcffib.Cookie):
     reply_type = GetPropertyContextReply
 
 
-@dataclass(init=False)
 class GetPropertyDataContextReply(xcffib.Reply):
     xge = False
 
@@ -227,12 +208,10 @@ class GetPropertyDataContextReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetPropertyDataContextCookie(xcffib.Cookie):
     reply_type = GetPropertyDataContextReply
 
 
-@dataclass(init=False)
 class ListPropertiesReply(xcffib.Reply):
     xge = False
 
@@ -246,12 +225,10 @@ class ListPropertiesReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class ListPropertiesCookie(xcffib.Cookie):
     reply_type = ListPropertiesReply
 
 
-@dataclass(init=False)
 class GetSelectionCreateContextReply(xcffib.Reply):
     xge = False
 
@@ -265,12 +242,10 @@ class GetSelectionCreateContextReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetSelectionCreateContextCookie(xcffib.Cookie):
     reply_type = GetSelectionCreateContextReply
 
 
-@dataclass(init=False)
 class GetSelectionUseContextReply(xcffib.Reply):
     xge = False
 
@@ -284,12 +259,10 @@ class GetSelectionUseContextReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetSelectionUseContextCookie(xcffib.Cookie):
     reply_type = GetSelectionUseContextReply
 
 
-@dataclass(init=False)
 class GetSelectionContextReply(xcffib.Reply):
     xge = False
 
@@ -303,12 +276,10 @@ class GetSelectionContextReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetSelectionContextCookie(xcffib.Cookie):
     reply_type = GetSelectionContextReply
 
 
-@dataclass(init=False)
 class GetSelectionDataContextReply(xcffib.Reply):
     xge = False
 
@@ -322,12 +293,10 @@ class GetSelectionDataContextReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetSelectionDataContextCookie(xcffib.Cookie):
     reply_type = GetSelectionDataContextReply
 
 
-@dataclass(init=False)
 class ListSelectionsReply(xcffib.Reply):
     xge = False
 
@@ -341,12 +310,10 @@ class ListSelectionsReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class ListSelectionsCookie(xcffib.Cookie):
     reply_type = ListSelectionsReply
 
 
-@dataclass(init=False)
 class GetClientContextReply(xcffib.Reply):
     xge = False
 
@@ -360,12 +327,10 @@ class GetClientContextReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetClientContextCookie(xcffib.Cookie):
     reply_type = GetClientContextReply
 
 
-@dataclass(init=False)
 class xselinuxExtension(xcffib.Extension):
     def QueryVersion(self, client_major, client_minor, is_checked=True):
         buf = io.BytesIO()
