@@ -1,7 +1,6 @@
 import xcffib
 import struct
 import io
-from dataclasses import dataclass
 
 MAJOR_VERSION = 2
 MINOR_VERSION = 2
@@ -12,7 +11,6 @@ from . import xproto
 from . import shm
 
 
-@dataclass(init=False)
 class Type:
     InputMask = 1 << 0
     OutputMask = 1 << 1
@@ -21,25 +19,21 @@ class Type:
     ImageMask = 1 << 4
 
 
-@dataclass(init=False)
 class ImageFormatInfoType:
     RGB = 0
     YUV = 1
 
 
-@dataclass(init=False)
 class ImageFormatInfoFormat:
     Packed = 0
     Planar = 1
 
 
-@dataclass(init=False)
 class AttributeFlag:
     Gettable = 1 << 0
     Settable = 1 << 1
 
 
-@dataclass(init=False)
 class VideoNotifyReason:
     Started = 0
     Stopped = 1
@@ -48,13 +42,11 @@ class VideoNotifyReason:
     HardError = 4
 
 
-@dataclass(init=False)
 class ScanlineOrder:
     TopToBottom = 0
     BottomToTop = 1
 
 
-@dataclass(init=False)
 class GrabPortStatus:
     Success = 0
     BadExtension = 1
@@ -64,7 +56,6 @@ class GrabPortStatus:
     BadAlloc = 5
 
 
-@dataclass(init=False)
 class Rational(xcffib.Struct):
     xge = False
 
@@ -91,7 +82,6 @@ class Rational(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class Format(xcffib.Struct):
     xge = False
 
@@ -118,7 +108,6 @@ class Format(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class AdaptorInfo(xcffib.Struct):
     xge = False
 
@@ -169,7 +158,6 @@ class AdaptorInfo(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class EncodingInfo(xcffib.Struct):
     xge = False
 
@@ -218,7 +206,6 @@ class EncodingInfo(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class Image(xcffib.Struct):
     xge = False
 
@@ -270,7 +257,6 @@ class Image(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class AttributeInfo(xcffib.Struct):
     xge = False
 
@@ -305,7 +291,6 @@ class AttributeInfo(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class ImageFormatInfo(xcffib.Struct):
     xge = False
 
@@ -437,7 +422,6 @@ class ImageFormatInfo(xcffib.Struct):
         return self
 
 
-@dataclass(init=False)
 class BadPortError(xcffib.Error):
     xge = False
 
@@ -460,7 +444,6 @@ BadBadPort = BadPortError
 _errors[0] = BadPortError
 
 
-@dataclass(init=False)
 class BadEncodingError(xcffib.Error):
     xge = False
 
@@ -483,7 +466,6 @@ BadBadEncoding = BadEncodingError
 _errors[1] = BadEncodingError
 
 
-@dataclass(init=False)
 class BadControlError(xcffib.Error):
     xge = False
 
@@ -506,7 +488,6 @@ BadBadControl = BadControlError
 _errors[2] = BadControlError
 
 
-@dataclass(init=False)
 class VideoNotifyEvent(xcffib.Event):
     xge = False
 
@@ -542,7 +523,6 @@ class VideoNotifyEvent(xcffib.Event):
 _events[0] = VideoNotifyEvent
 
 
-@dataclass(init=False)
 class PortNotifyEvent(xcffib.Event):
     xge = False
 
@@ -578,7 +558,6 @@ class PortNotifyEvent(xcffib.Event):
 _events[1] = PortNotifyEvent
 
 
-@dataclass(init=False)
 class QueryExtensionReply(xcffib.Reply):
     xge = False
 
@@ -591,12 +570,10 @@ class QueryExtensionReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class QueryExtensionCookie(xcffib.Cookie):
     reply_type = QueryExtensionReply
 
 
-@dataclass(init=False)
 class QueryAdaptorsReply(xcffib.Reply):
     xge = False
 
@@ -610,12 +587,10 @@ class QueryAdaptorsReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class QueryAdaptorsCookie(xcffib.Cookie):
     reply_type = QueryAdaptorsReply
 
 
-@dataclass(init=False)
 class QueryEncodingsReply(xcffib.Reply):
     xge = False
 
@@ -629,12 +604,10 @@ class QueryEncodingsReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class QueryEncodingsCookie(xcffib.Cookie):
     reply_type = QueryEncodingsReply
 
 
-@dataclass(init=False)
 class GrabPortReply(xcffib.Reply):
     xge = False
 
@@ -647,12 +620,10 @@ class GrabPortReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GrabPortCookie(xcffib.Cookie):
     reply_type = GrabPortReply
 
 
-@dataclass(init=False)
 class QueryBestSizeReply(xcffib.Reply):
     xge = False
 
@@ -665,12 +636,10 @@ class QueryBestSizeReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class QueryBestSizeCookie(xcffib.Cookie):
     reply_type = QueryBestSizeReply
 
 
-@dataclass(init=False)
 class GetPortAttributeReply(xcffib.Reply):
     xge = False
 
@@ -683,12 +652,10 @@ class GetPortAttributeReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetPortAttributeCookie(xcffib.Cookie):
     reply_type = GetPortAttributeReply
 
 
-@dataclass(init=False)
 class QueryPortAttributesReply(xcffib.Reply):
     xge = False
 
@@ -702,12 +669,10 @@ class QueryPortAttributesReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class QueryPortAttributesCookie(xcffib.Cookie):
     reply_type = QueryPortAttributesReply
 
 
-@dataclass(init=False)
 class ListImageFormatsReply(xcffib.Reply):
     xge = False
 
@@ -721,12 +686,10 @@ class ListImageFormatsReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class ListImageFormatsCookie(xcffib.Cookie):
     reply_type = ListImageFormatsReply
 
 
-@dataclass(init=False)
 class QueryImageAttributesReply(xcffib.Reply):
     xge = False
 
@@ -744,12 +707,10 @@ class QueryImageAttributesReply(xcffib.Reply):
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class QueryImageAttributesCookie(xcffib.Cookie):
     reply_type = QueryImageAttributesReply
 
 
-@dataclass(init=False)
 class xvExtension(xcffib.Extension):
     def QueryExtension(self, is_checked=True):
         buf = io.BytesIO()
